import{a0 as r}from"./index-DPOJo1e5.js";const a=r("appname",{state:()=>({appName:"Bomiot"}),getters:{appModeDataGet(e){return e.appName}},actions:{appModeChange(e){this.appName=e}},persist:{enable:!0}}),i=r("rightDrawer",{state:()=>({rightDrawerMenu:!1,rightDrawerOpen:!1}),getters:{rightDrawerMenuGet(e){return e.rightDrawerMenu},rightDrawerOpenGet(e){return e.rightDrawerOpen}},actions:{controlRightDrawer(e){this.rightDrawerOpen=e},toggleRightDrawer(){this.rightDrawerOpen===!1?this.rightDrawerOpen=!0:this.rightDrawerOpen=!1},controlRightDrawerMenu(e){this.rightDrawerMenu=e}},persist:{enable:!0}});export{i as a,a as u};
