<!DOCTYPE html>
<html>
  <head>

    <meta charset="utf-8">
    <meta name="format-detection" content="telephone=no">
    <meta name="msapplication-tap-highlight" content="no">
    <meta name="viewport" content="user-scalable=no, initial-scale=1, maximum-scale=1, minimum-scale=1, width=device-width<% if (ctx.mode.cordova || ctx.mode.capacitor) { %>, viewport-fit=cover<% } %>">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@48,400,0,0" />
    <style>
        ::-webkit-scrollbar {
          width : 12px;
        }
        ::-webkit-scrollbar-thumb {
          background: -webkit-linear-gradient(transparent,#30ff);
          border-radius : 6px;
        }
        ::-webkit-scrollbar-thumb:hover {
          background: -webkit-linear-gradient(transparent,#00c6ff);
        }
    </style>
    <link rel="icon" type="image/png" href="icons/logo.png">
  </head>
  <body>
    <!-- quasar:entry-point -->
  </body>
</html>
